Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Connection ¶
type Connection struct {
*Options
// Sender is the channel used for sending out data to the client.
// This channel gets mapped for the next handler to use with the right type
// and is asynchronous unless the SendChannelBuffer is set to 0.
Sender reflect.Value
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.